==> zio-aws-datazone_2.13-7.21.15.5-sources.jar: zio/aws/datazone/model/SearchGroupProfilesResponse.scala <==
package zio.aws.datazone.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.datazone.model.primitives.PaginationToken
import scala.jdk.CollectionConverters._
final case class SearchGroupProfilesResponse(
    items: Optional[Iterable[zio.aws.datazone.model.GroupProfileSummary]] =
      Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse = {
    import SearchGroupProfilesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.datazone.model.SearchGroupProfilesResponse.ReadOnly =
    zio.aws.datazone.model.SearchGroupProfilesResponse.wrap(buildAwsValue())
}
object SearchGroupProfilesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datazone.model.SearchGroupProfilesResponse =
      zio.aws.datazone.model.SearchGroupProfilesResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items
        : Optional[List[zio.aws.datazone.model.GroupProfileSummary.ReadOnly]]
    def nextToken: Optional[PaginationToken]
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.datazone.model.GroupProfileSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse
  ) extends zio.aws.datazone.model.SearchGroupProfilesResponse.ReadOnly {
    override val items
        : Optional[List[zio.aws.datazone.model.GroupProfileSummary.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.datazone.model.GroupProfileSummary.wrap(item)
          }.toList
        )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.datazone.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse
  ): zio.aws.datazone.model.SearchGroupProfilesResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-datazone_3-7.21.15.11-sources.jar: zio/aws/datazone/model/SearchGroupProfilesResponse.scala <==
package zio.aws.datazone.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.datazone.model.primitives.PaginationToken
import scala.jdk.CollectionConverters.*
final case class SearchGroupProfilesResponse(
    items: Optional[Iterable[zio.aws.datazone.model.GroupProfileSummary]] =
      Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse = {
    import SearchGroupProfilesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.datazone.model.SearchGroupProfilesResponse.ReadOnly =
    zio.aws.datazone.model.SearchGroupProfilesResponse.wrap(buildAwsValue())
}
object SearchGroupProfilesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datazone.model.SearchGroupProfilesResponse =
      zio.aws.datazone.model.SearchGroupProfilesResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items
        : Optional[List[zio.aws.datazone.model.GroupProfileSummary.ReadOnly]]
    def nextToken: Optional[PaginationToken]
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.datazone.model.GroupProfileSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse
  ) extends zio.aws.datazone.model.SearchGroupProfilesResponse.ReadOnly {
    override val items
        : Optional[List[zio.aws.datazone.model.GroupProfileSummary.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.datazone.model.GroupProfileSummary.wrap(item)
          }.toList
        )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.datazone.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datazone.model.SearchGroupProfilesResponse
  ): zio.aws.datazone.model.SearchGroupProfilesResponse.ReadOnly = new Wrapper(
    impl
  )
}
